/************************************************************************/
/*    File Version: V1.00                                               */
/*   History    :1.0A (2013-08-19)  [Hardware Manual Revision : 1.50]   */
/*              :1.0B (2019-03-18)  [Hardware Manual Revision : 1.50]   */
/*    Date Generated: 03/18/2019                                        */
/************************************************************************/

#include "interrupt_handlers.h"

typedef void (*fp) (void);
extern void PowerON_Reset (void);
extern void stack (void);

#define FVECT_SECT          __attribute__ ((section (".fvectors")))

const void *HardwareVectors[] FVECT_SECT  = {
//;0xffffff80  MDES  Endian Select Register
#ifdef __RX_LITTLE_ENDIAN__ 
(fp)0xffffffff,
#endif
#ifdef __RX_BIG_ENDIAN__ 
(fp)0xfffffff8,
#endif
//;0xffffff84  Reserved
    (fp)0,
//;0xffffff88  OFS1
    (fp)0xFFFFFFFF,
//;0xffffff8C  OFS0
    (fp)0xFFFFFFFF,
//;0xffffff90  Reserved
    (fp)0,
//;0xffffff94  Reserved
    (fp)0,
//;0xffffff98  Reserved
    (fp)0,
//;0xffffff9C  Reserved
    (fp)0,
//;0xffffffA0  Reserved
    (fp)0xFFFFFFFF,
//;0xffffffA4  Reserved
    (fp)0xFFFFFFFF,
//;0xffffffA8  Reserved
    (fp)0xFFFFFFFF,
//;0xffffffAC  Reserved
    (fp)0xFFFFFFFF,
//;0xffffffB0  Reserved
    (fp)0,
//;0xffffffB4  Reserved
    (fp)0,
//;0xffffffB8  Reserved
    (fp)0,
//;0xffffffBC  Reserved
    (fp)0,
//;0xffffffC0  Reserved
    (fp)0,
//;0xffffffC4  Reserved
    (fp)0,
//;0xffffffC8  Reserved
    (fp)0,
//;0xffffffCC  Reserved
    (fp)0,
//;0xffffffd0  Exception(Supervisor Instruction)
    INT_Excep_SuperVisorInst,
//;0xffffffd4  Reserved
    INT_Excep_AccessInst,
//;0xffffffd8  Reserved
    (fp)0,
//;0xffffffdc  Exception(Undefined Instruction)
    INT_Excep_UndefinedInst,
//;0xffffffe0  Reserved
    (fp)0,
//;0xffffffe4  Exception(Floating Point)
    INT_Excep_FloatingPoint,
//;0xffffffe8  Reserved
    (fp)0,
//;0xffffffec  Reserved
    (fp)0,
//;0xfffffff0  Reserved
    (fp)0,
//;0xfffffff4  Reserved
    (fp)0,
//;0xfffffff8  NMI
    INT_NonMaskableInterrupt,
//;0xfffffffc  RESET
//;<<VECTOR DATA START (POWER ON RESET)>>
//;Power On Reset PC
    PowerON_Reset                                                                                                                  
//;<<VECTOR DATA END (POWER ON RESET)>>
};

#define RVECT_SECT          __attribute__ ((section (".rvectors")))

const fp RelocatableVectors[] RVECT_SECT  = {
//;0x0000  Reserved
    (fp)0,
//;0x0004  Reserved
    (fp)0,
//;0x0008  Reserved
    (fp)0,
//;0x000C  Reserved
    (fp)0,
//;0x0010  Reserved
    (fp)0,
//;0x0014  Reserved
    (fp)0,
//;0x0018  Reserved
    (fp)0,
//;0x001C  Reserved
    (fp)0,
//;0x0020  Reserved
    (fp)0,
//;0x0024  Reserved
    (fp)0,
//;0x0028  Reserved
    (fp)0,
//;0x002C  Reserved
    (fp)0,
//;0x0030  Reserved
    (fp)0,
//;0x0034  Reserved
    (fp)0,
//;0x0038  Reserved
    (fp)0,
//;0x003C  Reserved
    (fp)0,
//;0x0040  BUSERR
    (fp)INT_Excep_BSC_BUSERR,
//;0x0044  Reserved
    (fp)0,
//;0x0048  Reserved
    (fp)0,
//;0x004C  Reserved
    (fp)0,
//;0x0050  Reserved
    (fp)0,
//;0x0054 FCUERR
    (fp)INT_Excep_FCU_FIFERR,
//;0x0058  Reserved
    (fp)0,
//;0x005C  FRDYI
    (fp)INT_Excep_FCU_FRDYI,
//;0x0060  Reserved
    (fp)0,
//;0x0064  Reserved
    (fp)0,
//;0x0068  Reserved
    (fp)0,
//;0x006C  SWINT
    (fp)INT_Excep_ICU_SWINT,
//;0x0070  CMTU0_CMT0
    (fp)INT_Excep_CMT0_CMI0,
//;0x0074  CMTU0_CMT1
    (fp)INT_Excep_CMT1_CMI1,
//;0x0078  CMTU1_CMT2
    (fp)INT_Excep_CMT2_CMI2,
//;0x007C  CMTU1_CMT3
    (fp)INT_Excep_CMT3_CMI3,
//;0x0080  Reserved
    (fp)0,
//;0x0084  D0FIFO0
    (fp)INT_Excep_USB0_D0FIFO0,
//;0x0088  D1FIFO0
    (fp)INT_Excep_USB0_D1FIFO0,
//;0x008C  USBIO
    (fp)INT_Excep_USB0_USBI0,
//;0x0090  Reserved
    (fp)0,
//;0x0094  Reserved
    (fp)0,
//;0x0098  Reserved
    (fp)0,
//;0x009C  RSPI0
    (fp)INT_Excep_RSPI0_SPRI0,
//;0x00A0  RSPI0
    (fp)INT_Excep_RSPI0_SPTI0,
//;0x00A4  RSPI0
    (fp)INT_Excep_RSPI0_SPII0,
//;0x00A8  RSPI1
    (fp)INT_Excep_RSPI1_SPRI1,
//;0x00AC  RSPI1
    (fp)INT_Excep_RSPI1_SPTI1,
//;0x00B0  RSPI1
    (fp)INT_Excep_RSPI1_SPII1,
//;0x00B4  RSPI2
    (fp)INT_Excep_RSPI2_SPRI2,
//;0x00B8  RSPI2
    (fp)INT_Excep_RSPI2_SPTI2,
//;0x00BC  RSPI2
    (fp)INT_Excep_RSPI2_SPII2,
//;0x00C0  CAN0
    (fp)INT_Excep_CAN0_RXF0,
//;0x00C4  CAN0
    (fp)INT_Excep_CAN0_TXF0,
//;0x00C8  CAN0
    (fp)INT_Excep_CAN0_RXM0,
//;0x00CC  CAN0
    (fp)INT_Excep_CAN0_TXM0,
//;0x00D0  CAN1
    (fp)INT_Excep_CAN1_RXF1,
//;0x00D4  CAN1
    (fp)INT_Excep_CAN1_TXF1,
//;0x00D8  CAN1
    (fp)INT_Excep_CAN1_RXM1,
//;0x00DC  CAN1
    (fp)INT_Excep_CAN1_TXM1,
//;0x00E0  CAN2
    (fp)INT_Excep_CAN2_RXF2,
//;0x00E4  CAN2
    (fp)INT_Excep_CAN2_TXF2,
//;0x00E8  CAN2
    (fp)INT_Excep_CAN2_RXM2,
//;0x00EC  CAN2
    (fp)INT_Excep_CAN2_TXM2,
//;0x00F0  Reserved
    (fp)0,
//;0x00F4  Reserved
    (fp)0,
//;0x00F8  RTC
    (fp)INT_Excep_RTC_CUP,
//;0x00FC  Reserved
    (fp)0,
//;0x0100  IRQ0
    (fp)INT_Excep_ICU_IRQ0,
//;0x0104 IRQ1
    (fp)INT_Excep_ICU_IRQ1,
//;0x0108 IRQ2
    (fp)INT_Excep_ICU_IRQ2,
//;0x010C IRQ3
    (fp)INT_Excep_ICU_IRQ3,
//;0x0110 IRQ4
    (fp)INT_Excep_ICU_IRQ4,
//;0x0114 IRQ5
    (fp)INT_Excep_ICU_IRQ5,
//;0x0118 IRQ6
    (fp)INT_Excep_ICU_IRQ6,
//;0x011C IRQ7
    (fp)INT_Excep_ICU_IRQ7,
//;0x0120 IRQ8
    (fp)INT_Excep_ICU_IRQ8,
//;0x0124 IRQ9
    (fp)INT_Excep_ICU_IRQ9,
//;0x0128 IRQ10
    (fp)INT_Excep_ICU_IRQ10,
//;0x012C IRQ11
    (fp)INT_Excep_ICU_IRQ11,
//;0x0130 IRQ12
    (fp)INT_Excep_ICU_IRQ12,
//;0x0134 IRQ13
    (fp)INT_Excep_ICU_IRQ13,
//;0x0138 IRQ14
    (fp)INT_Excep_ICU_IRQ14,
//;0x013C IRQ15
    (fp)INT_Excep_ICU_IRQ15,
//;0x0140  Reserved
    (fp)0,
//;0x0144  Reserved
    (fp)0,
//;0x0148  Reserved
    (fp)0,
//;0x014C  Reserved
    (fp)0,
//;0x0150  Reserved
    (fp)0,
//;0x0154  Reserved
    (fp)0,
//;0x0158  Reserved
    (fp)0,
//;0x015C  Reserved
    (fp)0,
//;0x0160  Reserved
    (fp)0,
//;0x0164  Reserved
    (fp)0,
//;0x0168  USB Resume
    (fp)INT_Excep_USB_USBR0,
//;0x016C  Reserved
    (fp)0,
//;0x0170  RTC
    (fp)INT_Excep_RTC_ALM,
//;0x0174  Reserved
    (fp)INT_Excep_RTC_PRD,
//;0x0178  Reserved
    (fp)0,
//;0x017C  Reserved
    (fp)0,
//;0x0180  Reserved
    (fp)0,
//;0x0184  Reserved
    (fp)0,
//;0x0188  AD0_ADI0
    (fp)INT_Excep_AD_ADI0,
//;0x018C  Reserved
    (fp)0,
//;0x0190  Reserved
    (fp)0,
//;0x0194  Reserved
    (fp)0,
//;0x0198  S12AD0_S12ADI0
    (fp)INT_Excep_S12AD_S12ADI0,
//;0x019C  Reserved
    (fp)0,
//;0x01A0  Reserved
    (fp)0,
//;0x01A4  Reserved
    (fp)0,
//;0x01A8  group_e0
    (fp)INT_Excep_ICU_GROUP0,
//;0x01AC  group_e1
    (fp)INT_Excep_ICU_GROUP1,
//;0x01B0  group_e2
    (fp)INT_Excep_ICU_GROUP2,
//;0x01B4  group_e3
    (fp)INT_Excep_ICU_GROUP3,
//;0x01B8  group_e4
    (fp)INT_Excep_ICU_GROUP4,
//;0x01BC  group_e5
    (fp)INT_Excep_ICU_GROUP5,
//;0x01C0  group_e6
    (fp)INT_Excep_ICU_GROUP6,
//;0x01C4  Reserved
    (fp)0,
//;0x01C8  group_IO
    (fp)INT_Excep_ICU_GROUP12,
//;0x01CC  Reserved
    (fp)0,
//;0x01D0  Reserved
    (fp)0,
//;0x01D4  Reserved
    (fp)0,
//;0x01D8  Reserved
    (fp)0,
//;0x01DC  Reserved
    (fp)0,
//;0x01E0  Reserved
    (fp)0,
//;0x01E4  Reserved
    (fp)0,
//;0x01E8  SCIX_ERI0
    (fp)INT_Excep_SCI12_SCIX0,
//;0x01EC  SCIX_RXI0
    (fp)INT_Excep_SCI12_SCIX1,
//;0x01F0  SCIX_TXI0
    (fp)INT_Excep_SCI12_SCIX2,
//;0x01F4  SCIX_TEI0
    (fp)INT_Excep_SCI12_SCIX3,
//;0x01F8  TPU0_TGI0A
    (fp)INT_Excep_TPU0_TGI0A,
//;0x01FC  TPU0_TGI0B
    (fp)INT_Excep_TPU0_TGI0B,
//;0x0200  TPU0_TGI0C
    (fp)INT_Excep_TPU0_TGI0C,
//;0x0204  TPU0_TGI0D
    (fp)INT_Excep_TPU0_TGI0D,
//;0x0208  TPU1_TGI1A
    (fp)INT_Excep_TPU1_TGI1A,
//;0x020C  TPU1_TGI1B
    (fp)INT_Excep_TPU1_TGI1B,
//;0x0210  TPU2_TGI2A
    (fp)INT_Excep_TPU2_TGI2A,
//;0x0214  TPU2_TGI2B
    (fp)INT_Excep_TPU2_TGI2B,
//;0x0218  TPU3_TGI3A
    (fp)INT_Excep_TPU3_TGI3A,
//;0x021C  TPU3_TGI3B
    (fp)INT_Excep_TPU3_TGI3B,
//;0x0220  TPU3_TGI3C
    (fp)INT_Excep_TPU3_TGI3C,
//;0x0224  TPU3_TGI3D
    (fp)INT_Excep_TPU3_TGI3D,
//;0x0228  TPU4_TGI4A
    (fp)INT_Excep_TPU4_TGI4A,
//;0x022C  TPU4_TGI4B
    (fp)INT_Excep_TPU4_TGI4B,
//;0x0230  TPU5_TGI5A
    (fp)INT_Excep_TPU5_TGI5A,
//;0x0234  TPU5_TGI5B
    (fp)INT_Excep_TPU5_TGI5B,
//;0x0238  MTU0_TGI0A / TPU6_TGI6A
    (fp)INT_Excep_TPU6_TGI6A,
//;0x023C  MTU0_TGI0B / TPU6_TGI6B
    (fp)INT_Excep_TPU6_TGI6B,
//;0x0240  MTU0_TGI0C / TPU6_TGI6C
    (fp)INT_Excep_TPU6_TGI6C,
//;0x0244  MTU0_TGI0D / TPU6_TGI6D
    (fp)INT_Excep_TPU6_TGI6D,
//;0x0248  MTU0_TGIE0
    (fp)INT_Excep_MTU0_TGIE0,
//;0x024C  MTU0_TGIF0
    (fp)INT_Excep_MTU0_TGIF0,
//;0x0250  MTU1_TGI1A / TPU7_TG7A
    (fp)INT_Excep_TPU7_TGI7A,
//;0x0254  MTU1_TGI1B / TPU7_TG7B
    (fp)INT_Excep_TPU7_TGI7B,
//;0x0258  MTU2_TGI2A / TPU8_TGI8A
    (fp)INT_Excep_TPU8_TGI8A,
//;0x025C  MTU2_TGI2B / TPU8_TGI8B
    (fp)INT_Excep_TPU8_TGI8B,
//;0x0260  MTU3_TGI3A / TPU9_TGI9A
    (fp)INT_Excep_TPU9_TGI9A,
//;0x0264  MTU3_TGI3B / TPU9_TGI9B
    (fp)INT_Excep_TPU9_TGI9B,
//;0x0268  MTU3_TGI3C / TPU9_TGI9C
    (fp)INT_Excep_TPU9_TGI9C,
//;0x026C  MTU3_TGI3D / TPU9_TGI9D
    (fp)INT_Excep_TPU9_TGI9D,
//;0x0270  MTU4_TGI4A / TPU10_TGI10A
    (fp)INT_Excep_TPU10_TGI10A,
//;0x0274  MTU4_TGI4B / TPU10_TGI10B
    (fp)INT_Excep_TPU10_TGI10B,
//;0x0278  MTU4_TGI4C
    (fp)INT_Excep_MTU4_TGIC4,
//;0x027C  MTU4_TGI4D
    (fp)INT_Excep_MTU4_TGID4,
//;0x0280  MTU4_TGI4V
    (fp)INT_Excep_MTU4_TCIV4,
//;0x0284  MTU5_TGI5U
    (fp)INT_Excep_MTU5_TGIU5,
//;0x0288  TPU11_TGI5V
    (fp)INT_Excep_MTU5_TGIV5,
//;0x028C  TPU11_TGI5W
    (fp)INT_Excep_MTU5_TGIW5,
//;0x0290  TPU11_TGI11A
    (fp)INT_Excep_TPU11_TGI11A,
//;0x0294  TPU11_TGI11B
    (fp)INT_Excep_TPU11_TGI11B,
//;0x0298  POE2 OEI1
    (fp)INT_Excep_POE_OEI1,
//;0x029C  POE2 OEI2
    (fp)INT_Excep_POE_OEI2,
//;0x02A0  Reserved
    (fp)0,
//;0x02A4  Reserved
    (fp)0,
//;0x02A8  TMR0_CMI0A
    (fp)INT_Excep_TMR0_CMIA0,
//;0x02AC  TMR0_CMI0B
    (fp)INT_Excep_TMR0_CMIB0,
//;0x02B0  TMR0_OV0I
    (fp)INT_Excep_TMR0_OVI0,
//;0x02B4  TMR1_CMI1A
    (fp)INT_Excep_TMR1_CMIA1,
//;0x02B8  TMR1_CMI1B
    (fp)INT_Excep_TMR1_CMIB1,
//;0x02BC  TMR1_OV1I
    (fp)INT_Excep_TMR1_OVI1,
//;0x02C0 TMR2_CMI2A
    (fp)INT_Excep_TMR2_CMIA2,
//;0x02C4  TMR2_CMI2B
    (fp)INT_Excep_TMR2_CMIB2,
//;0x02C8  TMR2_OV2I
    (fp)INT_Excep_TMR2_OVI2,
//;0x02CC  TMR3_CMI3A
    (fp)INT_Excep_TMR3_CMIA3,
//;0x02D0 TMR3_CMI3B
    (fp)INT_Excep_TMR3_CMIB3,
//;0x02D4  TMR3_OV3I
    (fp)INT_Excep_TMR3_OVI3,
//;0x02D8  RIIC0
    (fp)INT_Excep_RIIC0_EEI0,
//;0x02DC  RIIC0
    (fp)INT_Excep_RIIC0_RXI0,
//;0x02E0  RIIC0
    (fp)INT_Excep_RIIC0_TXI0,
//;0x02E4  RIIC0
    (fp)INT_Excep_RIIC0_TEI0,
//;0x02E8  RIIC1
    (fp)INT_Excep_RIIC1_EEI1,
//;0x02EC  RIIC1
    (fp)INT_Excep_RIIC1_RXI1,
//;0x02F0  RIIC1
    (fp)INT_Excep_RIIC1_TXI1,
//;0x02F4  RIIC1
    (fp)INT_Excep_RIIC1_TEI1,
//;0x02F8  RIIC2
    (fp)INT_Excep_RIIC2_EEI2,
//;0x02FC  RIIC2
    (fp)INT_Excep_RIIC2_RXI2,
//;0x0300  RIIC2
    (fp)INT_Excep_RIIC2_TXI2,
//;0x0304  RIIC2
    (fp)INT_Excep_RIIC2_TEI2,
//;0x0308  RIIC3_EEI3
	(fp)INT_Excep_RIIC3_EEI3,
//;0x030C  RIIC3_RXI3
	(fp)INT_Excep_RIIC3_RXI3,
//;0x0310  RIIC3_TXI3
	(fp)INT_Excep_RIIC3_TXI3,
//;0x0314  RIIC3_TEI3
	(fp)INT_Excep_RIIC3_TEI3,
//;0x0318  DMAC_DMAC0I
    (fp)INT_Excep_DMAC_DMAC0I,
//;0x031C  DMAC_DMTEND1
    (fp)INT_Excep_DMAC_DMAC1I,
//;0x0320  DMAC_DMTEND2
    (fp)INT_Excep_DMAC_DMAC2I,
//;0x0324  DMAC_DMTEND3
    (fp)INT_Excep_DMAC_DMAC3I,
//;0x0328  Reserved
    (fp)0,
//;0x032C  Reserved
    (fp)0,
//;0x0330  Reserved
    (fp)0,
//;0x0334  Reserved
    (fp)0,
//;0x0338  Reserved
    (fp)0,
//;0x033C  Reserved
    (fp)0,
//;0x0340  Reserved
    (fp)0,
//;0x0344  Reserved
    (fp)0,
//;0x0348  Reserved
    (fp)0,
//;0x034C  Reserved
    (fp)0,
//;0x0350  Reserved
    (fp)0,
//;0x0354  Reserved
    (fp)0,
//;0x0358  SCI0_RXI0
    (fp)INT_Excep_SCI0_RXI0,
//;0x035C  SCI0_TXI0
    (fp)INT_Excep_SCI0_TXI0,
//;0x0360  SCI0_TEI0
    (fp)INT_Excep_SCI0_TEI0,
//;0x0364  SCI1_RXI1
    (fp)INT_Excep_SCI1_RXI1,
//;0x0368  SCI1_TXI1
    (fp)INT_Excep_SCI1_TXI1,
//;0x036C  SCI1_TEI1
    (fp)INT_Excep_SCI1_TEI1,
//;0x0370  SCI2_RXI2
    (fp)INT_Excep_SCI2_RXI2,
//;0x0374  SCI2_TXI2
    (fp)INT_Excep_SCI2_TXI2,
//;0x0378  SCI2_TEI2
    (fp)INT_Excep_SCI2_TEI2,
//;0x037C  SCI3_RXI3
    (fp)INT_Excep_SCI3_RXI3,
//;0x0380  SCI3_TXI3
    (fp)INT_Excep_SCI3_TXI3,
//;0x0384  SCI3_TEI3
    (fp)INT_Excep_SCI3_TEI3,
//;0x0388  SCI4_RXI4
    (fp)INT_Excep_SCI4_RXI4,
//;0x038C  SCI4_TXI4
    (fp)INT_Excep_SCI4_TXI4,
//;0x0390  SCI4_TEI4
    (fp)INT_Excep_SCI4_TEI4,
//;0x0394  SCI5_RXI5
    (fp)INT_Excep_SCI5_RXI5,
//;0x0398  SCI5_TXI5
    (fp)INT_Excep_SCI5_TXI5,
//;0x039C  SCI5_TEI5
    (fp)INT_Excep_SCI5_TEI5,
//;0x03A0  SCI6_RXI6
    (fp)INT_Excep_SCI6_RXI6,
//;0x03A4  SCI6_TXI6
    (fp)INT_Excep_SCI6_TXI6,
//;0x03A8  SCI6_TEI6
    (fp)INT_Excep_SCI6_TEI6,
//;0x03AC  SCI7_RXI7
    (fp)INT_Excep_SCI7_RXI7,
//;0x03B0  SCI7_TXI7
    (fp)INT_Excep_SCI7_TXI7,
//;0x03B4  SCI7_TEI7
    (fp)INT_Excep_SCI7_TEI7,
//;0x03B8  SCI8_RXI8
    (fp)INT_Excep_SCI8_RXI8,
//;0x03BC  SCI8_TXI8
    (fp)INT_Excep_SCI8_TXI8,
//;0x03C0  SCI8_TEI8
    (fp)INT_Excep_SCI8_TEI8,
//;0x03C4  SCI9_RXI9
    (fp)INT_Excep_SCI9_RXI9,
//;0x03C8  SCI9_TXI9
    (fp)INT_Excep_SCI9_TXI9,
//;0x03CC  SCI9_TEI9
    (fp)INT_Excep_SCI9_TEI9,
//;0x03D0  SCI10_RXI0
    (fp)INT_Excep_SCI10_RXI10,
//;0x03D4  SCI10_TXI0
    (fp)INT_Excep_SCI10_TXI10,
//;0x03D8  SCI10_TEI0
    (fp)INT_Excep_SCI10_TEI10,
//;0x03DC  SCI11_RXI1
    (fp)INT_Excep_SCI11_RXI11,
//;0x03E0  SCI11_TXI1
    (fp)INT_Excep_SCI11_TXI11,
//;0x03E4  SCI11_TEI1
    (fp)INT_Excep_SCI11_TEI11,
//;0x03E8  SCI12_RXI2
    (fp)INT_Excep_SCI12_RXI12,
//;0x03EC  SCI12_TXI2
    (fp)INT_Excep_SCI12_TXI12,
//;0x03F0  SCI12_TEI2
    (fp)INT_Excep_SCI12_TEI12,
//;0x03F4  IEBUS IEBINT
    (fp)INT_Excep_IEB_IEBINT,
//;0x03F8  Reserved
    (fp)0,
//;0x03FC  Reserved
    (fp)0,
};
