/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2022 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system                           *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.16.1.0                                        *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
File    : sbrk.c
Purpose : Provides sbrk() implementation for Newlib.
*/

#include <_ansi.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <errno.h>

caddr_t sbrk(int incr) {
  extern char  _heap_start[];         // Defined by the linker script.
  extern char  _heap_end[];           // Defined by the linker script.
  static char* _heap_limit = NULL;
         char* prev_heap_limit;

  if (_heap_limit == NULL) {
    _heap_limit = _heap_start;
  }

  if (_heap_limit + incr > _heap_end) {
    errno = ENOMEM;
    return (caddr_t)-1;
  }

  prev_heap_limit = _heap_limit;
  _heap_limit    += incr;

  return (caddr_t)prev_heap_limit;
}

/*************************** End of file ****************************/
